| Title: | ICA Atlas for the 'ggseg' Ecosystem |
|---|---|
| Description: | Probabilistic independent component analysis (ICA) cortical atlas for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with 2D polygon geometry for use with 'ggseg'. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.0.1 |
| Built: | 2026-05-26 06:17:44 UTC |
| Source: | https://github.com/ggsegverse/ggsegIca |
Brain atlas for the probabilistic independent component analysis (ICA)
cortical parcellation with 163 regions. Contains 2D polygon geometry
for ggseg::geom_brain().
ica()ica()
A ggseg.formats::ggseg_atlas object (cortical).
Beckmann CF, Smith SM (2004). Probabilistic Independent Component Analysis for Functional Magnetic Resonance Imaging. IEEE Transactions on Medical Imaging, 23(2):137-152. doi:10.1109/TMI.2003.822821
ica() plot(ica())ica() plot(ica())